@@ -1,5 +1,6 @@
 Data2fd <- function(argvals=NULL, y=NULL, basisobj=NULL, nderiv=NULL,
-                    lambda=3e-8/diff(range(argvals)), fdnames=NULL)
+                    lambda=3e-8/diff(range(argvals)), fdnames=NULL, 
+                    covariates=NULL, method="chol", dfscale=1)
 {
 ## Change proposed by Spencer Graves 2011.01.10:
 ## Default lambda = NULL here,
@@ -164,7 +165,8 @@ Data2fd <- function(argvals=NULL, y=NULL, basisobj=NULL, nderiv=NULL,
 #
   smBasis <- with(argChk, smooth.basisPar(argvals=argvals, y=y,
                 fdobj=basisobj, Lfdobj=nderiv, lambda=lambda,
-                fdnames=fdnames) )
+                fdnames=fdnames, 
+                covariates=covariates, method="chol", dfscale=dfscale) )
 #
   smBasis$fd
 }
