@@ -1,17 +1,26 @@
 "[.fd" <- function(fdobj, i=TRUE, j=TRUE, drop=TRUE) {
   #  select subsets of curves in a functional data object
 
-  coef    <- fdobj$coefs
+  coef    <- as.array(fdobj$coefs)
   fdnames <- fdobj$fdnames
-  ndim    <- length(dim(coef))
+  coefdim <- dim(coef)
+  ndim    <- length(coefdim)
 
   if(ndim == 2) {
-    coefselect <- coef[, i,drop=FALSE]
-    if(length(fdnames[[2]])>1){
+    if (coefdim[2] == 1) {
+      coefselect <- coef
+    } else {
+      coefselect <- coef[, i, drop=FALSE]
+    }
+    if (length(fdnames[[2]])>1) {
 	    fdnames[[2]] = fdnames[[2]][i]
     }
   } else {
-    coefselect <- coef[, i, j,drop=drop]
+    if (coefdim[2] == 1) {
+      coefselect <- coef
+    } else {
+      coefselect <- coef[, i, j,drop=drop]
+    }
     if(length(fdnames[[2]])>1){
 	    fdnames[[2]] = fdnames[[2]][i]
     }
